_kshiftli_mask8

Function _kshiftli_mask8 

1.89.0 (const: unstable) · Source
pub fn _kshiftli_mask8(a: __mmask8, const COUNT: u32) -> __mmask8
Available on (x86 or x86-64) and target feature avx512dq only.
Shift 8-bit mask a left by count bits while shifting in zeros, and store the result in dst.

Intel’s Documentation